References
===========

Orbital Mechanics
-----------------

.. [OM1] Fundamentals of Astrodynamics and Applications 4th Ed. David A. Vallado. Microcosm Press, 2013., ISBN: 978-11881883203


.. [OM2] A-B-Cs of sun-synchronous orbit mission design. Ronald Boain. 14th AAS/AIAA Space Flight Mechanics Meeting,
    Maui, HI, February 8-12, 2004.

Time and Coordinate Frames
--------------------------

.. [TCF1] IERS Conventions (2010). Gérard Petit and Brian Luzum (eds.). (IERS Technical Note ; 36) Frankfurt am Main;
    Verlag des Bundesamts für Kartographie und Geodäsie, 2010. 179 pp., ISBN: 3-89888-989-6
